package jalview.appletgui;

import jalview.datamodel.*;
import jalview.analysis.*;
import jalview.jbappletgui.GTreePanel;
import java.awt.event.*;
import java.util.*;
import jalview.io.NewickFile;


public class TreePanel extends GTreePanel
{
  SequenceI[] seq;
  String type;
  String pwtype;
  AlignViewport av;
  int start;
  int end;
  TreeCanvas treeCanvas;
  NJTree tree;

  public NJTree getTree()
  {
    return tree;
  }

  public TreePanel(AlignViewport av, Vector seqVector, String type, String pwtype, int s, int e)
  {
    super();

    this.type = type;
    this.pwtype = pwtype;

    start = s;
    end = e;

    String longestName = "";
    seq = new Sequence [seqVector.size()];
    for (int i=0;i < seqVector.size();i++)
    {
      seq[i] = (Sequence) seqVector.elementAt(i);
      if(seq[i].getName().length()>longestName.length())
        longestName = seq[i].getName();
    }

    tree = new NJTree(seq, type, pwtype, start, end);

    treeCanvas = new TreeCanvas(av, tree, scrollPane, longestName);

    tree.reCount(tree.getTopNode());
    tree.findHeight(tree.getTopNode());
    scrollPane.add(treeCanvas);

  }

public TreePanel(AlignViewport av, Vector seqVector, NewickFile newtree,
               String type, String pwtype)
{
  super();
  // These are probably only  arbitrary strings reflecting source of tree
  this.type = type;
  this.pwtype = pwtype;

  start = 0;
  end = seqVector.size();

  String longestName = "";
  seq = new Sequence [seqVector.size()];
  for (int i=0;i < seqVector.size();i++)
  {
    seq[i] = (Sequence) seqVector.elementAt(i);
    if(seq[i].getName().length()>longestName.length())
      longestName = seq[i].getName();
  }
  // This constructor matches sequence names to treenodes and sets up the tree layouts.
  tree = new NJTree(seq, newtree);

  tree.reCount(tree.getTopNode());
  tree.findHeight(tree.getTopNode());

  treeCanvas = new TreeCanvas(av, tree, scrollPane, longestName);
  treeCanvas.setShowBootstrap(newtree.HasBootstrap());
  bootstrapMenu.setState(newtree.HasBootstrap());
  treeCanvas.setShowDistances(newtree.HasDistances());
  distanceMenu.setState(newtree.HasDistances());
  scrollPane.add(treeCanvas);

}



public String getText(String format) {
  return null;
}

  protected void fitToWindow_actionPerformed(ActionEvent e)
  {
    treeCanvas.fitToWindow = fitToWindow.getState();
    repaint();
  }

  public void newickOutput_actionPerformed(ActionEvent actionEvent)
  {
    jalview.io.NewickFile fout = new jalview.io.NewickFile(tree.getTopNode());
    String output = fout.print(false, true);
    CutAndPasteTransfer cap = new CutAndPasteTransfer(false);
    cap.setText(output);
    java.awt.Frame frame = new java.awt.Frame();
    frame.add(cap);
    jalview.bin.JalviewLite.addFrame(frame, type+" "+pwtype, 500,500);
  }



  protected void fontSize_actionPerformed(ActionEvent e)
  {
 /*   if( treeCanvas==null )
     return;

   String size = fontSize.getLabel().substring( fontSize.getLabel().indexOf("-")+1);

   Object selection = JOptionPane.showInternalInputDialog(Desktop.desktop,
                               "Select font size",
                               "Font size",
                               JOptionPane.QUESTION_MESSAGE,
                               null, new String[]{"1","2","4","6","8","10","12","14","16","18","20"}
                               ,"Font Size - "+size);
   if(selection!=null)
   {
     fontSize.setText("Font Size - " + selection);

     int i = Integer.parseInt(selection.toString());
     treeCanvas.setFontSize(i);
   }
    scrollPane.setViewportView(treeCanvas);
*/
  }

  protected void distanceMenu_actionPerformed(ActionEvent e)
  {
    treeCanvas.setShowDistances(distanceMenu.getState());
  }

  protected void bootstrapMenu_actionPerformed(ActionEvent e)
  {
    treeCanvas.setShowBootstrap(bootstrapMenu.getState());
  }

}
